Module rusty_dumb_tools::calc
source · Expand description
A simple infix calculation processor – crate::calc::DumbCalcProcessor
Structs
- A simple infix calculation processor that accepts a stream of “calculation units” and evaluate the result; Please refer to
DumbCalcProcessor::pushfor the acceptable “calculation units”
Enums
- calculation result, which can be one of three kinds